/******************************************************************************
 The computer software and associated documentation called DOMAK hereinafter
 referred to as the WORK which is more particularly identified and described in
 Appendix A of the file LICENSE.  Conditions and restrictions for use of
 this package are also in this file.

 This routine was developed by Robert B. Russell



 All use of the WORK must cite:
 Siddiqui, A. S. and Barton, G. J., "Continuous and Discontinuous Domains: An
 Algorithm for the Automatic Generation of Reliable Protein Domain Definitions" 
 PROTEIN SCIENCE, 4:872-884 (1995).
*****************************************************************************/
/* $Id: rmsp.c,v 1.4 2004/09/10 14:39:17 geoff Exp $ */

#include <stdio.h>


/* This routine removes spaces from a string and returns the result. */

void RBR_rmsp(c)
char *c;
{
	int i,j;
	char *temp;

	temp=(char*)malloc((strlen(c)+1)*sizeof(char));
	i=0; j=0;
	while(c[i] !='\0') {
	   if(c[i]!=' ') temp[j++]=c[i];
	   i++;
	} /* End of while. */
	temp[j]='\0';
	strcpy(c,temp);
	free(temp);
	return;
} /* End of routine. */

